fitted.smoothbp_fit: Fitted values for smoothbp_fit objects

View source: R/postprocess.R

fitted.smoothbp_fitR Documentation

Fitted values for smoothbp_fit objects

Description

Fitted values for smoothbp_fit objects

Usage

## S3 method for class 'smoothbp_fit'
fitted(object, newdata = NULL, summary = TRUE, ...)

Arguments

object

A smoothbp_fit object.

newdata

Optional data frame for prediction.

summary

Logical; if TRUE (default), returns the mean and 95% CI of the fitted values.

...

Unused.

Value

If summary = TRUE, a data.frame containing the observation index, mean fitted value, and 95% CI bounds. If summary = FALSE, a matrix of dimension S x N where S is the number of posterior draws and N is the number of observations, containing the posterior draws of the fitted values.


smoothbp documentation built on June 14, 2026, 9:06 a.m.