log_lik: Pointwise log-likelihood matrix

View source: R/generics.R

log_likR Documentation

Pointwise log-likelihood matrix

Description

Pointwise log-likelihood matrix

Usage

log_lik(object, ...)

## S3 method for class 'smoothbp_fit'
log_lik(object, ...)

Arguments

object

A smoothbp_fit object.

...

Unused.

Value

A matrix of pointwise log-likelihood values of dimension S x N, where S is the number of posterior draws and N is the number of observations.


smoothbp documentation built on June 14, 2026, 9:06 a.m.