| fitted.smoothbp_fit | R Documentation |
Fitted values for smoothbp_fit objects
## S3 method for class 'smoothbp_fit'
fitted(object, newdata = NULL, summary = TRUE, ...)
object |
A |
newdata |
Optional data frame for prediction. |
summary |
Logical; if |
... |
Unused. |
If summary = TRUE, a data.frame containing the observation index, mean fitted value, and 95% CI bounds. If summary = FALSE, a matrix of dimension S x N where S is the number of posterior draws and N is the number of observations, containing the posterior draws of the fitted values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.