| smoothbp_priors | R Documentation |
Each argument accepts either:
A single prior_normal() applied to all coefficients of that parameter, or
A named list mapping coefficient names (matching column names of the design
matrix) to individual prior_normal() objects.
smoothbp_priors(
b0 = prior_normal(0, 10),
b1 = prior_normal(0, 2),
deltas = prior_normal(0, 2),
omega = prior_normal(3, 2, lb = 0),
rho = prior_normal(3, 2, lb = 0),
sigma = prior_invgamma(1, 1),
sigma_u = prior_invgamma(1, 1),
sigma_re_om = prior_invgamma(1, 1),
sigma_re_b1 = prior_invgamma(1, 1),
sigma_re_deltas = prior_invgamma(1, 1)
)
b0 |
Prior(s) for |
b1 |
Prior(s) for |
deltas |
Prior(s) for slope change coefficients (one list per segment). |
omega |
Prior(s) for |
rho |
Prior(s) for |
sigma |
|
sigma_u |
|
sigma_re_om |
|
sigma_re_b1 |
|
sigma_re_deltas |
|
For multi-breakpoint models, deltas, omega, and rho can also be
lists of prior specifications (one per breakpoint slot). If a single
specification is provided, it is applied to all slots.
A smoothbp_priors list.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.