| update.smoothbp_fit | R Documentation |
Re-fits the model, replacing any arguments supplied here with the corresponding values stored in the original fit for anything left unspecified.
## S3 method for class 'smoothbp_fit'
update(
object,
formula,
b0,
b1,
deltas,
omega,
rho,
data,
priors,
chains,
iter,
warmup,
seed,
step_om,
step_rho,
target_accept,
cores,
.verbose = TRUE,
...
)
object |
A |
formula, b0, b1, deltas, omega, rho, data, priors, chains, iter, warmup, seed, step_om, step_rho, target_accept, cores, .verbose |
Replacements for the corresponding arguments of |
... |
Ignored. |
A new smoothbp_fit object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.